@@ -28,9 +28,13 @@
 
 This AWS Solutions Construct implements an AWS WAF web ACL connected to Amazon CloudFront.
 
-Here is a minimal deployable pattern definition in Typescript:
+Here is a minimal deployable pattern definition:
+
+Typescript
 
 ```python
+import { Construct } from 'constructs';
+import { Stack, StackProps } from 'aws-cdk-lib';
 import { CloudFrontToS3 } from '@aws-solutions-constructs/aws-cloudfront-s3';
 import { WafwebaclToCloudFront } from "@aws-solutions-constructs/aws-wafwebacl-cloudfront";
 
@@ -42,17 +46,41 @@ new WafwebaclToCloudFront(this, 'test-wafwebacl-cloudfront', {
 });
 ```
 
-## Initializer
+Python
 
-```text
-new WafwebaclToCloudFront(scope: Construct, id: string, props: WafwebaclToCloudFrontProps);
+```python
+from aws_solutions_constructs.aws_cloudfront_s3 import CloudFrontToS3
+from aws_solutions_constructs.aws_wafwebacl_cloudfront import WafwebaclToCloudFront
+from aws_cdk import Stack
+from constructs import Construct
+
+cloudfront_to_s3 = CloudFrontToS3(self, 'test_cloudfront_s3')
+
+# This construct can only be attached to a configured CloudFront.
+WafwebaclToCloudFront(self, 'test_wafwebacl_cloudfront',
+                      existing_cloud_front_web_distribution=cloudfront_to_s3.cloud_front_web_distribution
+                      )
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`WafwebaclToCloudFrontProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awsconstructs.services.cloudfronts3.*;
+import software.amazon.awsconstructs.services.wafwebaclcloudfront.*;
+
+final CloudFrontToS3 cloudfrontToS3 = new CloudFrontToS3(this, "test-cloudfront-s3",
+        new CloudFrontToS3Props.Builder()
+                .build());
+
+// This construct can only be attached to a configured CloudFront.
+new WafwebaclToCloudFront(this, "test-wafwebacl-cloudfront", new WafwebaclToCloudFrontProps.Builder()
+        .existingCloudFrontWebDistribution(cloudfrontToS3.getCloudFrontWebDistribution())
+        .build());
+```
 
 ## Pattern Construct Props
 
