@@ -14,17 +14,14 @@ import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_wafv2._jsii
 import aws_cdk.core._jsii
-import aws_solutions_constructs.aws_cloudfront_apigateway_lambda._jsii
-import aws_solutions_constructs.aws_cloudfront_mediastore._jsii
-import aws_solutions_constructs.aws_cloudfront_s3._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-wafwebacl-cloudfront",
-    "1.146.0",
+    "1.150.0",
     __name__[0:-6],
-    "aws-wafwebacl-cloudfront@1.146.0.jsii.tgz",
+    "aws-wafwebacl-cloudfront@1.150.0.jsii.tgz",
 )
 
 __all__ = [
